pub struct PackageConfig {
pub path: PathBuf,
pub resolver: EcosystemId,
pub publish: Option<bool>,
pub channel: ReleaseChannel,
pub channel_bump: Option<ChannelBump>,
pub assets: Vec<Asset>,
pub github_release: Option<bool>,
pub depends_on: Vec<PackageId>,
}Fields
path: PathBufPath to the package root directory.
resolver: EcosystemIdResolver type to use.
publish: Option<bool>Optional override for manifest- or plugin-derived publishability.
channel: ReleaseChannelRelease channel to use. Stable is the default and is omitted when saved.
channel_bump: Option<ChannelBump>One-shot stable-base override for the next transition into channel.
assets: Vec<Asset>Assets to publish.
github_release: Option<bool>Whether to create a GitHub Release for this package.
depends_on: Vec<PackageId>Supplemental internal dependency edges keyed by stable package ID.
Implementations
Sourceimpl PackageConfig
impl PackageConfig
pub fn effective_publishable(&self, adapter_publishable: bool) -> bool
pub fn github_release_enabled(&self, publishable: bool) -> bool